@@ -74,11 +74,12 @@ int ffgcls( fitsfile *fptr,   /* I - FITS file pointer                       */
   Returns a formated string value, regardless of the datatype of the column
 */
 {
-    int tcode, hdutype, tstatus, scaled, intcol, dwidth, nulwidth, ll;
+    int tcode, hdutype, tstatus, scaled, intcol, dwidth, nulwidth, ll, dlen;
+    int equivtype;
     long ii, jj;
     tcolumn *colptr;
     char message[FLEN_ERRMSG], *carray, keyname[FLEN_KEYWORD];
-    char cform[20], dispfmt[20], tmpstr[80], *flgarray, tmpnull[80];
+    char cform[20], dispfmt[20], tmpstr[400], *flgarray, tmpnull[80];
     unsigned char byteval;
     float *earray;
     double *darray, tscale = 1.0;
@@ -104,6 +105,10 @@ int ffgcls( fitsfile *fptr,   /* I - FITS file pointer                       */
         return(*status = BAD_COL_NUM);
     }
 
+    /* get equivalent dataype of column (only needed for TLONGLONG columns) */
+    ffeqtyll(fptr, colnum, &equivtype, NULL, NULL, status);
+    if (equivtype < 0) equivtype = abs(equivtype);
+    
     colptr  = (fptr->Fptr)->tableptr;   /* point to first column */
     colptr += (colnum - 1);     /* offset to correct column structure */
     tcode = abs(colptr->tdatatype);
@@ -274,7 +279,7 @@ int ffgcls( fitsfile *fptr,   /* I - FITS file pointer                       */
 
       free(darray);  /* free the memory */
     }
-    else if (tcode == TLONGLONG)
+    else if (tcode == TLONGLONG && equivtype == TLONGLONG)
     {
       /* allocate memory for the array of LONGLONG values */
       llarray = (LONGLONG *) calloc((size_t) nelem, sizeof(LONGLONG) );
@@ -390,6 +395,11 @@ int ffgcls( fitsfile *fptr,   /* I - FITS file pointer                       */
                   /* scaled long integer column == double */
                   strcpy(cform, "%#23.15G");
             }
+            else if (scaled && tcode == TLONGLONG)
+            {
+                  /* scaled long long integer column == double */
+                  strcpy(cform, "%#23.15G");
+            }
             else
             {
                ffghdt(fptr, &hdutype, status);
@@ -455,10 +465,17 @@ int ffgcls( fitsfile *fptr,   /* I - FITS file pointer                       */
            }
            else
            {	   
-              if (intcol)
+              if (intcol) {
                 sprintf(tmpstr, cform, (int) darray[ii]);
-              else
+              } else {
                 sprintf(tmpstr, cform, darray[ii]);
+              }
+	      
+              /* fill field with '*' if number is too wide */
+              dlen = strlen(tmpstr);
+	      if (dlen > dwidth) {
+	         memset(tmpstr, '*', dwidth);
+              }
 
               *array[ii] = '\0';
               strncat(array[ii], tmpstr, dwidth);
@@ -561,6 +578,12 @@ int ffgcdw( fitsfile *fptr,   /* I - FITS file pointer                       */
             /* scaled long integer col == double; default format is 23.15G */
             *width = 23;
         }
+        else if (scaled && tcode == TLONGLONG)
+        {
+            /* scaled long long integer col == double; default format is 23.15G */
+            *width = 23;
+        }
+
         else
         {
            ffghdt(fptr, &hdutype, status);  /* get type of table */
@@ -598,13 +621,28 @@ int ffgcdw( fitsfile *fptr,   /* I - FITS file pointer                       */
                      *width = 1;
                   else if (tcode == TSTRING)   /* 'A' */
                   {
-                     cptr = dispfmt;
-                     while(!isdigit((int) *cptr) && *cptr != '\0') 
-                         cptr++;
+		    int typecode;
+		    long int repeat = 0, rwidth = 0;
+		    int gstatus = 0;
 
-                     *width = atoi(cptr);
+		    /* Deal with possible vector string with repeat / width  by parsing
+		       the TFORM=rAw keyword */
+		    if (ffgtcl(fptr, colnum, &typecode, &repeat, &rwidth, &gstatus) == 0 &&
+			rwidth >= 1 && rwidth < repeat) {
+		      *width = rwidth;
 
-                     if (*width < 1)
+		    } else {
+		      
+		      /* Hmmm, we couldn't parse the TFORM keyword by standard, so just do
+			 simple parsing */
+		      cptr = dispfmt;
+		      while(!isdigit((int) *cptr) && *cptr != '\0') 
+			cptr++;
+		      
+		      *width = atoi(cptr);
+		    }
+
+                    if (*width < 1)
                          *width = 1;  /* default is at least 1 column */
                   }
             }
@@ -691,6 +729,15 @@ int ffgcls2 ( fitsfile *fptr,   /* I - FITS file pointer                       *
         &repeat, &rowlen, &hdutype, &tnull, snull, status) > 0)
         return(*status);
 
+      /* if string length is greater than a FITS block (2880 char) then must */
+      /* only read 1 string at a time, to force reading by ffgbyt instead of */
+      /* ffgbytoff (ffgbytoff can't handle this case) */
+      if (twidth > IOBUFLEN) {
+        maxelem = 1;
+        incre = twidth;
+        repeat = 1;
+      }   
+
       remain = nelem;
     }
     else
@@ -726,7 +773,7 @@ int ffgcls2 ( fitsfile *fptr,   /* I - FITS file pointer                       *
 
     while (remain)
     {
-      /* limit the number of pixels to process a one time to the number that
+      /* limit the number of pixels to process at one time to the number that
          will fit in the buffer space or to the number of pixels that remain
          in the current vector, which ever is smaller.
       */
